@@ -78,7 +78,8 @@ EXTENSIONS = {
     'jade': {'text', 'jade'},
     'jar': {'binary', 'zip', 'jar'},
     'java': {'text', 'java'},
-    'jenkinsfile': {'text', 'groovy'},
+    'jenkins': {'text', 'groovy', 'jenkins'},
+    'jenkinsfile': {'text', 'groovy', 'jenkins'},
     'jinja': {'text', 'jinja'},
     'jinja2': {'text', 'jinja'},
     'jpeg': {'binary', 'image', 'jpeg'},
@@ -270,10 +271,12 @@ NAMES = {
     'Dockerfile': {'text', 'dockerfile'},
     'Gemfile': EXTENSIONS['rb'],
     'Gemfile.lock': {'text'},
-    'Jenkinsfile': {'text', 'groovy'},
+    'GNUmakefile': EXTENSIONS['mk'],
+    'Jenkinsfile': EXTENSIONS['jenkins'],
     'LICENSE': EXTENSIONS['txt'],
     'MAINTAINERS': EXTENSIONS['txt'],
     'Makefile': EXTENSIONS['mk'],
+    'makefile': EXTENSIONS['mk'],
     'NEWS': EXTENSIONS['txt'],
     'NOTICE': EXTENSIONS['txt'],
     'PATENTS': EXTENSIONS['txt'],
